@@ -1,8 +1,9 @@
 ##' Conditional regression for microbiome analysis based on multivariate zero-inflated logistic normal model
 ##'
-##' Make inference on the associations of microbiome with covariates given a user-specified reference taxon/OTU/ASV.
+##' For estimating and testing the associations of abundance ratios with covariates.
 ##' \loadmathjax
 ##'
+##' Most of the time, users just need to feed the first six inputs to the function: `MicrobData`, `CovData`,  `linkIDname`, `targetTaxa`, `refTaxa` and `allCov`. All other inputs can just take their default values.
 ##' The regression model for `MZILN()` can be expressed as follows:
 ##' \mjdeqn{\log\bigg(\frac{\mathcal{Y}_i^k}{\mathcal{Y}_i^{K+1}}\bigg)|\mathcal{Y}_i^k>0,\mathcal{Y}_i^{K+1}>0=\alpha^{0k}+\mathcal{X}_i^T\alpha^k+\epsilon_i^k,\hspace{0.2cm}k=1,...,K}{}
 ##' where
@@ -14,33 +15,32 @@
 ##'
 ##' High-dimensional \mjeqn{X_i}{} is handled by regularization.
 ##'
-##' @param MicrobData Microbiome data matrix containing microbiome abundance with each row
-##' per sample and each column per taxon/OTU/ASV. It should contain an `"id"` variable to
-##' correspond to the `"id"` variable in the covariates data: `CovData`. This argument can
+##' @param MicrobData Microbiome data matrix containing microbiome absolute abundance or relative abundance with each row
+##' per sample and each column per taxon/OTU/ASV (or any other unit). It should contain an id variable to
+##' be linked with the id variable in the covariates data: `CovData`. This argument can
 ##' take directory path. For example, `MicrobData="C://...//microbiomeData.tsv"`.
 ##' @param CovData Covariates data matrix containing covariates and confounders with each row
-##' per sample and each column per variable. It should also contain an `"id"` variable to
-##' correspond to the `"id"` variable in the microbiome data: `MicrobData`. This argument can
+##' per sample and each column per variable. It should also contain an id variable to
+##' be linked with the id variable in the microbiome data: `MicrobData`. This argument can
 ##' take directory path. For example, `CovData="C://...//covariatesData.tsv"`.
 ##'
 ##'
-##' @param linkIDname Variable name of the `"id"` variable in both `MicrobData` and `CovData`. The two data sets will be merged by this `"id"` variable.
-##' @param allCov All covariates of interest (including confounders) for estimating and testing their associations with microbiome. Default is 'NULL' meaning that all covariates in covData are of interest.
-##' @param targetTaxa The taxa that should be used as numerator. Default is NULL.
-##' @param refTaxa Reference taxa specified by the user and will be used as the reference taxa.
-##' @param adjust_method The adjusting method used for p value adjustment. Same as p.adjust function in R.
-##' @param fdrRate The false discovery rate for identifying taxa/OTU/ASV associated with `allCov`. Default is `0.25`.
-##' @param sequentialRun This takes a logical value `TRUE` or `FALSE`. Default is `TRUE` since there is only 1 reference taxon.
-##' @param paraJobs If `sequentialRun` is `FALSE`, this specifies the number of parallel jobs that will be registered to run the algorithm. If specified as `NULL`, it will automatically detect the cores to decide the number of parallel jobs. Default is `NULL`. It is safe to have 4gb memory per job. It may be needed to reduce the number of jobs if memory is limited.
-##' @param standardize This takes a logical value `TRUE` or `FALSE`. If `TRUE`, all design matrix X in phase 1 and phase 2 will be standardized in the analyses. Default is `FALSE`.
-##' @param bootB Number of bootstrap samples for obtaining confidence interval of estimates in phase 2. The default is `500`.
-##' @param bootLassoAlpha The significance level in phase 2. Default is `0.05`.
-##' @param taxkeepThresh The threshold of number of non-zero sequencing reads for each taxon to be included into the analysis.
-##' @param seed Random seed for reproducibility. Default is `1`.
+##' @param linkIDname The common variable name of the id variable in both `MicrobData` and `CovData`. The two data sets will be merged by this id variable.
+##' @param targetTaxa The numerator taxa names specified by users for the targeted ratios. Default is NULL in which case all taxa are numerator taxa (except the taxa in the argument 'refTaxa').
+##' @param refTaxa Denominator taxa names specified by the user for the targeted ratios. This could be a vector of names.
+##' @param allCov All covariates of interest (including confounders) for estimating and testing their associations with the targeted ratios. Default is 'NULL' meaning that all covariates in covData are of interest.
+##' @param adjust_method The adjusting method for p value adjustment. Default is "BY" for dependent FDR adjustment. It can take any adjustment method for p.adjust function in R.
+##' @param fdrRate The false discovery rate for identifying taxa/OTU/ASV associated with `allCov`. Default is `0.15`.
+##' @param paraJobs If `sequentialRun` is `FALSE`, this specifies the number of parallel jobs that will be registered to run the algorithm. If specified as `NULL`, it will automatically detect the cores to decide the number of parallel jobs. Default is `NULL`.
+##' @param bootB Number of bootstrap samples for obtaining confidence interval of estimates for the high dimensional regression. The default is `500`.
+##' @param taxkeepThresh The threshold of number of non-zero sequencing reads for each taxon to be included into the analysis. The default is `1` which means taxon with at least `1` sequencing reads will be included into the analysis.
+##' @param standardize This takes a logical value `TRUE` or `FALSE`. If `TRUE`, all design matrix X in the analyses will be standardized. Default is `FALSE`.
+##' @param sequentialRun This takes a logical value `TRUE` or `FALSE`. Default is `TRUE`. It can be set to be "FALSE" to increase speed if there are multiple taxa in the argument 'refTaxa'.
+##' @param seed Random seed for reproducibility. Default is `1`. It can be set to be NULL to remove seeding.
 ##' @return A list containing the estimation results.
 ##'
-##' - `analysisResults$full_results`: A list containing estimating results for all significant taxa.
-##' - `analysisResults$targettaxa_result_list`: A list containing estimating results for targetTaxa. Only available when targetTaxa is non-empty.
+##'##' - `targettaxa_result_list`: A list containing estimating results for the targeted ratios. Only available when targetTaxa is non-empty.
+##' - `sig_results`: A list containing estimating results for all significant ratios
 ##' - `covariatesData`: A dataset containing all covariates used in the analyses.
 ##'
 ##' @examples
@@ -54,10 +54,10 @@
 ##' results <- MZILN(MicrobData = dataM,
 ##'                 CovData = dataC,
 ##'                 linkIDname = "id",
-##'                 allCov=c("v1","v2","v3"),
 ##'                 targetTaxa = "rawCount6",
 ##'                 refTaxa=c("rawCount11"),
-##'                 paraJobs=2)
+##'                 allCov=c("v1","v2","v3"),
+##'                 fdrRate=0.15)
 ##'
 ##' }
 ##'
@@ -76,15 +76,14 @@ MZILN=function(
   MicrobData,
   CovData,
   linkIDname,
-  allCov=NULL,
   targetTaxa=NULL,
   refTaxa,
+  allCov=NULL,
   adjust_method="BY",
-  fdrRate=0.2,
+  fdrRate=0.15,
   paraJobs=NULL,
   bootB=500,
-  bootLassoAlpha=0.05,
-  taxkeepThresh=0,
+  taxkeepThresh=1,
   standardize=FALSE,
   sequentialRun=TRUE,
   seed=1
@@ -94,7 +93,6 @@ MZILN=function(
   results=list()
 
   start.time = proc.time()[3]
-  # MZILN=TRUE
   runMeta=metaData(MicrobData=MicrobData,CovData=CovData,
                    linkIDname=linkIDname,testCov=allCov,
                    taxkeepThresh=taxkeepThresh)
@@ -138,17 +136,18 @@ MZILN=function(
                                           targetTaxa=targetTaxa,
                                           refTaxa=refTaxa_newNam,adjust_method=adjust_method,
                                           paraJobs=paraJobs,fdrRate=fdrRate,
-                                          bootB=bootB,bootLassoAlpha=bootLassoAlpha,
+                                          bootB=bootB,
                                           standardize=standardize,sequentialRun=sequentialRun,
                                           allFunc=allFunc,seed=seed
   )
   rm(data)
 
+  results$sig_results<-results$analysisResults$sig_results
+  results$targettaxa_result_list<-results$analysisResults$targettaxa_result_list
   results$testCov=testCovInOrder
   results$ctrlCov=ctrlCov
   results$microbName=microbName
   results$bootB=bootB
-  results$bootLassoAlpha=bootLassoAlpha
   results$paraJobs=paraJobs
   results$nRef=nRef
 
@@ -165,11 +164,5 @@ MZILN=function(
 
   results$totalTimeMins=totalTimeMins
 
-  if (length(targetTaxa)>0) {
-    print(results$analysisResults$targettaxa_result_list)
-  } else {
-    print(results$analysisResults$all_cov_sig_list)
-  }
-
   return(results)
 }
